@@ -1,4 +1,4 @@
-module.exports = function (req, res) {
+export default function (req, res) {
   
   req.on('data', function (chunk) {
   });
